@@ -1,15 +1,16 @@
 package cmd
 
 import (
+	"strconv"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
+	"github.com/alecthomas/assert/v2"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
 )
 
-func Test_lastpassParseNote(t *testing.T) {
-	for _, tc := range []struct {
+func TestLastpassParseNote(t *testing.T) {
+	for i, tc := range []struct {
 		note     string
 		expected map[string]string
 	}{
@@ -20,9 +21,15 @@ func Test_lastpassParseNote(t *testing.T) {
 			},
 		},
 		{
-			note: "Foo:bar\nbaz\n",
+			note: chezmoitest.JoinLines(
+				"Foo:bar",
+				"baz",
+			),
 			expected: map[string]string{
-				"foo": "bar\nbaz\n",
+				"foo": chezmoitest.JoinLines(
+					"bar",
+					"baz",
+				),
 			},
 		},
 		{
@@ -52,6 +59,10 @@ func Test_lastpassParseNote(t *testing.T) {
 			},
 		},
 	} {
-		assert.Equal(t, tc.expected, lastpassParseNote(tc.note))
+		t.Run(strconv.Itoa(i), func(t *testing.T) {
+			actual, err := lastpassParseNote(tc.note)
+			assert.NoError(t, err)
+			assert.Equal(t, tc.expected, actual)
+		})
 	}
 }
